/*
 *    Copyright 2012, 2013 Thomas Schöps, Kai Pastor
 *
 *    This file is part of OpenOrienteering.
 *
 *    OpenOrienteering is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    OpenOrienteering is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with OpenOrienteering.  If not, see <http://www.gnu.org/licenses/>.
 */

/** This file is used by qmake-driven builds only. */

#ifndef OPENORIENTEERING_MAPPER_CONFIG_H
#define OPENORIENTEERING_MAPPER_CONFIG_H

#if !defined(APP_NAME)
#define APP_NAME qApp->translate("OpenOrienteering::Global", QT_TRANSLATE_NOOP("Global", "OpenOrienteering Mapper"))
#endif

#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS)
#define CPACK_DEBIAN_PACKAGE_NAME "openorienteering-mapper"
#define MAPPER_DEBIAN_PACKAGE_NAME CPACK_DEBIAN_PACKAGE_NAME
#endif

#endif
